/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2024 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system                           *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.18.3.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
File    : BSP.c
Purpose : BSP for ST STM32N657X0_Q_Nucleo
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

#define LED0_BIT         (8)     // LED1 / LD7, Blue,  connected to PG8,  active low
#define LED1_BIT         (0)     // LED3 / LD6, Green, connected to PG0,  active low
#define LED2_BIT         (10)    // LED2 / LD5, Red,   connected to PG10, active low
						 
#define RCC_BASE_ADDR    (0x56028000)
#define RCC_AHB4ENR      (*(volatile unsigned int*)(RCC_BASE_ADDR + 0x25Cu))
#define RCC_GPIOGEN_BIT  (6)
						 
#define GPIOG_BASE_ADDR  (0x56021800)
#define GPIOG_MODER      (*(volatile unsigned int*)(GPIOG_BASE_ADDR + 0x00u))  // GPIOG port mode register
#define GPIOG_IDR        (*(volatile unsigned int*)(GPIOG_BASE_ADDR + 0x10u))  // GPIOG input data register
#define GPIOG_BSRR       (*(volatile unsigned int*)(GPIOG_BASE_ADDR + 0x18u))  // GPIOG bit set/reset register

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  RCC_AHB4ENR |=  (1u << RCC_GPIOGEN_BIT);  // Enable GPIOG clock
  GPIOG_MODER &= ~(3u << (LED0_BIT * 2))    // Clear mode bits
              &  ~(3u << (LED1_BIT * 2))
              &  ~(3u << (LED2_BIT * 2));
  GPIOG_MODER |=  (1u << (LED0_BIT * 2))    // Set mode to output
              |   (1u << (LED1_BIT * 2))
              |   (1u << (LED2_BIT * 2));
  GPIOG_BSRR  |=  (1u << (LED0_BIT))        // Initially clear LEDs
              |   (1u << (LED1_BIT))
              |   (1u << (LED2_BIT));
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  switch (Index) {
  case 0:
	GPIOG_BSRR |= (1u << (LED0_BIT + 16u));
	break;
  case 1:
	GPIOG_BSRR |= (1u << (LED1_BIT + 16u));
	break;
  case 2:
	GPIOG_BSRR |= (1u << (LED2_BIT + 16u));
	break;
  default:
	break;
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  switch (Index) {
  case 0:
	GPIOG_BSRR |= (1u << (LED0_BIT));
	break;
  case 1:
	GPIOG_BSRR |= (1u << (LED1_BIT));
	break;
  case 2:
	GPIOG_BSRR |= (1u << (LED2_BIT));
	break;
  default:
	break;
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  switch (Index) {
  case 0:
    if (GPIOG_IDR & (1u << LED0_BIT)) {
      GPIOG_BSRR |= (1u << (LED0_BIT + 16u));
    } else {
      GPIOG_BSRR |= (1u << LED0_BIT);
    }
    break;
  case 1:
    if (GPIOG_IDR & (1u << LED1_BIT)) {
      GPIOG_BSRR |= (1u << (LED1_BIT + 16u));
    } else {
      GPIOG_BSRR |= (1u << LED1_BIT);
    }
    break;
  case 2:
    if (GPIOG_IDR & (1u << LED2_BIT)) {
      GPIOG_BSRR |= (1u << (LED2_BIT + 16u));
    } else {
      GPIOG_BSRR |= (1u << LED2_BIT);
    }
    break;
  default:
    break;
  }
}

/*************************** End of file ****************************/
